#
#   Skript zur Demo vrschiedner Konzepte im Rahmen der
#   "Einführung in Python" in der Reihe
#   "Dinge mit Daten" 
#   2024 Denis Arnold  
#   MIT License
#

# import notwendiger Module, bzw. Submodule und Funktionen

import os
from pathlib import Path
import zipfile
from urllib.request import urlretrieve
import pandas as pd
import matplotlib.pyplot as plt

# Dieser Teil sucht Euer Homeverzeichnis
# wechselt auf den Desktop
# erzeugt da einen Ordner
# und wechselt in den erstellten Ordner

home=Path.home()
os.chdir(str(home)+"/Desktop")
if os.path.exists("DmD_Python")==False:
    os.makedirs("DmD_Python")
os.chdir("DmD_Python")

# Dieser Teil lädt eine ZIP-Datei von EduLabs herunter
# und speichert sie in dem Ordner

url="https://www.edulabs.uni-koeln.de/goto_iliasedulabs_file_23317_download.html"
file_name="DmD_Python_Daten.zip"

urlretrieve(url,file_name)

# Dieser Teil entpackt die ZIP-Datei

with zipfile.ZipFile(file_name,"r") as zip_ref:
    zip_ref.extractall(".")

# In den entpackten Ordner wechseln
# alle Daten einlesen

os.chdir("okt2023")
files=os.listdir()
csv_files=[f for f in files if f.endswith(".csv")]

all_data=pd.DataFrame()

for i in csv_files:
    temp=pd.read_csv(i)
    all_data=pd.concat([all_data,temp])

# pandas versteht nicht sofort 
# wie es die Zeitstempel interpretieren muss

print(all_data.info())

# pandas kommt mit einer Funktion, mit der wir
# tstamp in ein Datumsobjekt umwandel können

all_data["tstamp"]=pd.to_datetime(all_data["tstamp"],format="%Y-%m-%d %H:%M:%S")

print(all_data.info())

# Die Daten sind sind z.T. noch durcheinander
# Wir sortieren sie einfach mit dieser Zeile:

all_data=all_data.sort_values("tstamp")

# Pandas kann uns auch direkt plots erzeugen
# Als Default benutzt es dafür matplotlib

all_data.plot("tstamp","num_occupancy",xlabel="Zeit",ylabel="Anzahl Personen")

plt.show()

